zonedSchedule method
Future<void>
zonedSchedule({
- required int id,
- String? title,
- String? body,
- required TZDateTime scheduledDate,
- String? payload,
- DateTimeComponents? matchDateTimeComponents,
- WindowsNotificationDetails? notificationDetails,
Schedules a notification to be shown at the specified date and time relative to a specific time zone.
Implementation
@override
Future<void> zonedSchedule({
required int id,
String? title,
String? body,
required TZDateTime scheduledDate,
String? payload,
DateTimeComponents? matchDateTimeComponents,
WindowsNotificationDetails? notificationDetails,
}) async {}